@@ -12,6 +12,7 @@
 #import "DataTab.h"
 #import "defs.h"
 #include <sys/stat.h>
+#import "ID3Tagger.h"
 
 @interface DataTab (PrivateAPI)
 - (NSString *)pathToColumn:(int)column;
@@ -184,19 +185,28 @@
  */
 - (void)copyFileToNJB:(NSString *)filename
 {
-	DataFile *dataFile = [DataFile dataFileFromPath:filename];
+	MyItem *dataFile = [DataFile dataFileFromPath:filename];
 	if (dataFile == nil)
 	{
 		// could not open, complain
 		return;
 	}
+  
+  if ([theNJB isAudioType:[dataFile fileType]])
+  {
+    ID3Tagger *tagger = [[ID3Tagger alloc] init];
+    [tagger setFilename:[dataFile fullPath]];
+    dataFile = [tagger readTrack];
+    [tagger release];
+  }
+  
 	[self copyDataFileToNJB:dataFile];
 }
 
 /* add the datafile dataFile to the queue
  * to be uploaded
  */
-- (void)copyDataFileToNJB:(DataFile *)dataFile
+- (void)copyDataFileToNJB:(MyItem *)dataFile
 {
 	// todo: stop duplicate files being copied and confusing us
 	if (![theNJB isConnected])
@@ -222,9 +232,18 @@
 		destDirPathComponents = [NSArray arrayWithArray:mutableComponents];
 	}
 	
-	NJBQueueItem *copyFile = [[NJBQueueItem alloc] initWithTarget:theNJB withSelector:@selector(uploadFile:toFolder:) withObject:dataFile];
-	[copyFile setObject2:[self makeNJBPathString:destDir]];
-	[copyFile setStatus:STATUS_UPLOADING_FILE];
+  NJBQueueItem *copyFile = nil;
+  if ([theNJB isAudioType:[dataFile fileType]])
+  {
+    copyFile = [[NJBQueueItem alloc] initWithTarget:theNJB withSelector:@selector(uploadTrack:) withObject:dataFile];
+    [copyFile setStatus:STATUS_UPLOADING_FILE];
+  }
+  else
+  {
+    copyFile = [[NJBQueueItem alloc] initWithTarget:theNJB withSelector:@selector(uploadFile:toFolder:) withObject:dataFile];
+    [copyFile setObject2:[self makeNJBPathString:destDir]];
+    [copyFile setStatus:STATUS_UPLOADING_FILE];
+  }
 		
 	NJBQueueItem *getUpdatedFileList = [[NJBQueueItem alloc] initWithTarget:self withSelector:@selector(downloadFileList)];
 	[getUpdatedFileList setDisplayStatus:NO];
