@@ -211,11 +211,13 @@
  */
 - (void)copyFileToNJB:(NSString *)filename
 {
-	ID3Tagger *tagger = [[ID3Tagger alloc] init];
-	[tagger setFilename:filename];
-	Track *track = [tagger readTrack];
+  Track *track = [[Track alloc] init];
+  [track setFullPath:filename];
+  [track fileTypeFromExtension];
+  
 	[self copyTrackToNJB:track];
-	[tagger release];
+  
+	[track release];
 }
 
 /* actually add the track to the queue
@@ -248,7 +250,8 @@
  */
 - (NJBTransactionResult *)uploadTrack:(Track *)track
 {
-	if (![preferences iTunesIntegration])
+  // assume we have no tag if title is empty - catch drag&drop tracks here
+	if (![preferences iTunesIntegration] || [[track title] length] == 0)
 	{
 		ID3Tagger *tagger = [[ID3Tagger alloc] init];
 		[tagger setFilename:[track fullPath]];
