@@ -196,16 +196,47 @@ StatusDisplayer *statusDisplayerGlobal;
 
 - (NSString *)njbErrorString
 {
-	const char *sp;
-	NSMutableString *errorString = [[NSMutableString alloc] init];
-	NJB_Error_Reset_Geterror(njb);
-  while ((sp = NJB_Error_Geterror(njb)) != NULL)
-	{
-		[errorString appendString:[NSString stringWithFormat:@"%s, ", sp]];
+  if (!mtpDevice)
+  {
+    const char *sp;
+    NSMutableString *errorString = [[NSMutableString alloc] init];
+    NJB_Error_Reset_Geterror(njb);
+    while ((sp = NJB_Error_Geterror(njb)) != NULL)
+    {
+      [errorString appendString:[NSString stringWithFormat:@"%s, ", sp]];
+    }
+    njb_error_clear(njb);
+    
+    NSString *errorString_immutable = [NSString stringWithString:errorString];
+    [errorString release];
+    return errorString_immutable;
+  }
+  else
+  {
+    if (device == NULL)
+      return nil;
+    
+    LIBMTP_error_t *errors = LIBMTP_Get_Errorstack(device);
+    
+    if (errors == NULL)
+      return nil;
+    
+    LIBMTP_error_t *cur_error = errors;
+    NSMutableString *errorString = [[NSMutableString alloc] init];
+    
+    while(cur_error != NULL)
+    {
+      // todo: check for NULL error_text
+      [errorString appendFormat:@"(%hu) %s;", cur_error->errornumber, cur_error->error_text];
+      cur_error = cur_error->next;
+    }
+    
+    LIBMTP_Clear_Errorstack(device);
+    
+    NSString *errorString_immutable = [NSString stringWithString:errorString];
+    [errorString release];
+    return errorString_immutable;
   }
-  njb_error_clear(njb);
-	
-	return [errorString autorelease];
 }
 
 /* connect to the NJB
@@ -284,7 +315,7 @@ StatusDisplayer *statusDisplayerGlobal;
 	
 	if (!connected)
 	{
-		return [[[NJBTransactionResult alloc] initWithSuccess:NO resultString:errorString] autorelease]; 
+    return [[[NJBTransactionResult alloc] initWithSuccess:NO resultString:errorString extendedErrorString:[self njbErrorString]] autorelease];
 	}
 	
 	[self updateDiskSpace];
@@ -339,7 +370,9 @@ StatusDisplayer *statusDisplayerGlobal;
 		if (LIBMTP_Get_Batterylevel(device, &batteryLevelMax, &currentLevel) != 0)
 		{
 			NSLog(@"Could not get battery level property description");
-			return 0;
+      NSString *errorString = [self njbErrorString];
+      NSLog(errorString);
+      return [[[NJBTransactionResult alloc] initWithSuccess:NO resultString:@"Could not get battry level property description" extendedErrorString:errorString] autorelease];
 		}
 		
 		LIBMTP_Get_Supported_Filetypes(device, &supportedFiletypes, &supportedFiletypesLength);
@@ -560,6 +593,9 @@ StatusDisplayer *statusDisplayerGlobal;
 		LIBMTP_track_t *tracks = LIBMTP_Get_Tracklisting_With_Callback(device, mtp_progress, &downloadingTracks);
 		if (tracks == NULL)
 		{
+      NSString *errorString = [self njbErrorString];
+      NSLog(errorString);
+      
 			downloadingTracks = NO;
 			return [self cachedTrackList];
 		}
@@ -692,8 +728,10 @@ StatusDisplayer *statusDisplayerGlobal;
 		{
 			NSString *error = @"Error uploading file";
 			NSLog(error);
+      NSString *errorString = [self njbErrorString];
+      NSLog(errorString);
 			LIBMTP_destroy_track_t(trackmeta);
-			return [[[NJBTransactionResult alloc] initWithSuccess:NO resultString:error] autorelease];
+			return [[[NJBTransactionResult alloc] initWithSuccess:NO resultString:error extendedErrorString:errorString] autorelease];
 		}
 		
 		[track setItemID:trackmeta->item_id];
@@ -739,7 +777,9 @@ StatusDisplayer *statusDisplayerGlobal;
 		{
 			NSString *error = @"error deleting track";
 			NSLog(error);
-			return [[[NJBTransactionResult alloc] initWithSuccess:NO resultString:error] autorelease];
+      NSString *errorString = [self njbErrorString];
+      NSLog(errorString);
+      return [[[NJBTransactionResult alloc] initWithSuccess:NO resultString:error extendedErrorString:errorString] autorelease];
 		}
 	}
 	
@@ -777,7 +817,9 @@ StatusDisplayer *statusDisplayerGlobal;
 		{
 			NSString *error = @"error deleting file";
 			NSLog(error);
-			return [[[NJBTransactionResult alloc] initWithSuccess:NO resultString:error] autorelease];
+      NSString *errorString = [self njbErrorString];
+      NSLog(errorString);
+      return [[[NJBTransactionResult alloc] initWithSuccess:NO resultString:error extendedErrorString:errorString] autorelease];
 		}
 	}
 	// update cache
@@ -819,7 +861,9 @@ StatusDisplayer *statusDisplayerGlobal;
 		{
 			NSString *error = @"Error downloading file";
 			NSLog(error);
-			return [[[NJBTransactionResult alloc] initWithSuccess:NO resultString:error] autorelease];
+      NSString *errorString = [self njbErrorString];
+      NSLog(errorString);
+      return [[[NJBTransactionResult alloc] initWithSuccess:NO resultString:error extendedErrorString:errorString] autorelease];
 		}
 	}
 	
@@ -870,7 +914,9 @@ StatusDisplayer *statusDisplayerGlobal;
 			NSString *error = @"Could not update track info";
 			NSLog(error);
 			LIBMTP_destroy_track_t(libmtp_track);
-			return [[[NJBTransactionResult alloc] initWithSuccess:NO resultString:error] autorelease];
+      NSString *errorString = [self njbErrorString];
+      NSLog(errorString);
+      return [[[NJBTransactionResult alloc] initWithSuccess:NO resultString:error extendedErrorString:errorString] autorelease];
 		}
 		LIBMTP_destroy_track_t(libmtp_track);
 	}
@@ -970,6 +1016,10 @@ StatusDisplayer *statusDisplayerGlobal;
 		if (files == NULL)
 		{
 			downloadingFiles = NO;
+      
+      NSString *errorString = [self njbErrorString];
+      NSLog(errorString);
+      
 			return nil;
 		}
 		
@@ -1031,7 +1081,9 @@ StatusDisplayer *statusDisplayerGlobal;
 		{
 			NSString *error = @"Error downloading file";
 			NSLog(error);
-			return [[[NJBTransactionResult alloc] initWithSuccess:NO resultString:error] autorelease];
+      NSString *errorString = [self njbErrorString];
+      NSLog(errorString);
+      return [[[NJBTransactionResult alloc] initWithSuccess:NO resultString:error extendedErrorString:errorString] autorelease];
 		}
 	}
 	
@@ -1078,10 +1130,12 @@ StatusDisplayer *statusDisplayerGlobal;
 			[newDir release];
 			if (![res success])
 			{
+        NSString *errorString = [self njbErrorString];
+        NSLog(errorString);
 				return [[[NJBTransactionResult alloc] initWithSuccess:NO
 																								 resultString:[NSString stringWithFormat:
 																									 @"Could not create containing directory %@", 
-																									 [Directory stringFromPathArray:destDirPathComponentsSoFar]]] autorelease];
+																									 [Directory stringFromPathArray:destDirPathComponentsSoFar]] extendedErrorString:errorString] autorelease];
 			}
 		}
 		else
@@ -1119,7 +1173,9 @@ StatusDisplayer *statusDisplayerGlobal;
 			NSString *error = @"Error uploading file";
 			NSLog(error);
 			LIBMTP_destroy_file_t(genfile);
-			return [[[NJBTransactionResult alloc] initWithSuccess:NO resultString:error] autorelease];
+      NSString *errorString = [self njbErrorString];
+      NSLog(errorString);
+      return [[[NJBTransactionResult alloc] initWithSuccess:NO resultString:error extendedErrorString:errorString] autorelease];
 		}
 		
 		[dataFile setItemID:genfile->item_id];
@@ -1241,7 +1297,9 @@ StatusDisplayer *statusDisplayerGlobal;
 		{
 			NSString *error = [NSString stringWithFormat:@"Could not set device friendly name"];
 			NSLog(error);
-			return [[[NJBTransactionResult alloc] initWithSuccess:NO resultString:error] autorelease];
+      NSString *errorString = [self njbErrorString];
+      NSLog(errorString);
+      return [[[NJBTransactionResult alloc] initWithSuccess:NO resultString:error extendedErrorString:errorString] autorelease];
 		}
 	}
 	return [[[NJBTransactionResult alloc] initWithSuccess:YES] autorelease];
@@ -1435,8 +1493,10 @@ StatusDisplayer *statusDisplayerGlobal;
 			if (LIBMTP_Create_New_Playlist(device, libmtpPlaylist, device->default_playlist_folder) != 0)
 			{
 				LIBMTP_destroy_playlist_t(libmtpPlaylist);
+				NSString *errorString = [self njbErrorString];
+				NSLog(errorString);
 				return [[[NJBTransactionResult alloc] initWithSuccess:NO resultString:
-					[NSString stringWithFormat:@"Could not create new playlist"]] autorelease];
+					[NSString stringWithFormat:@"Could not create new playlist"] extendedErrorString:errorString] autorelease];
 			}
 			[playlist lock];
 			[playlist setPlaylistID:libmtpPlaylist->playlist_id];
@@ -1447,8 +1507,10 @@ StatusDisplayer *statusDisplayerGlobal;
 			if (LIBMTP_Update_Playlist(device, libmtpPlaylist) != 0)
 			{
 				LIBMTP_destroy_playlist_t(libmtpPlaylist);
+				NSString *errorString = [self njbErrorString];
+				NSLog(errorString);        
 				return [[[NJBTransactionResult alloc] initWithSuccess:NO resultString:
-					[NSString stringWithFormat:@"Could not update playlist"]] autorelease];
+					[NSString stringWithFormat:@"Could not update playlist"] extendedErrorString:errorString] autorelease];
 			}
 			[playlist lock];
 			// it doesn't change the playlist now but put it in to be
@@ -1483,7 +1545,9 @@ StatusDisplayer *statusDisplayerGlobal;
 		{
 			NSString *error = @"error deleting playlist";
 			NSLog(error);
-			return [[[NJBTransactionResult alloc] initWithSuccess:NO resultString:error] autorelease];
+      NSString *errorString = [self njbErrorString];
+      NSLog(errorString);
+      return [[[NJBTransactionResult alloc] initWithSuccess:NO resultString:error extendedErrorString:errorString] autorelease];
 		}
 	}
 	
@@ -1624,8 +1688,12 @@ int mtp_progress (uint64_t const sent, uint64_t const total, void const * const
 		unsigned newDirID = LIBMTP_Create_Folder(device, [[dir name] UTF8String], [parentDir itemID]);
 		if (newDirID == 0)
 		{
+      NSString *errorString = [self njbErrorString];
+      NSLog(errorString);
+      
 			return [[[NJBTransactionResult alloc] initWithSuccess:NO 
-																							 resultString:[NSString stringWithFormat:@"Could not create folder with parent ID 0x%04.", [parentDir itemID]]] autorelease];
+																							 resultString:[NSString stringWithFormat:@"Could not create folder with parent ID 0x%04.", [parentDir itemID]]
+                                        extendedErrorString:errorString] autorelease];
 		}
 		[dir setItemID:newDirID];
 	}
@@ -1974,6 +2042,10 @@ int mtp_progress (uint64_t const sent, uint64_t const total, void const * const
     {
       LIBMTP_destroy_album_t(libmtpAlbum);
       NSLog(@"Could not create new album");
+      
+      NSString *errorString = [self njbErrorString];
+      NSLog(errorString);
+      
       return;
     }
     else
@@ -1990,6 +2062,10 @@ int mtp_progress (uint64_t const sent, uint64_t const total, void const * const
       
       if (ret != PTP_RC_OK || props == NULL) {
         NSLog(@"could not get supported properties for type PTP_OFC_MTP_AbstractAudioAlbum.");
+        
+        NSString *errorString = [self njbErrorString];
+        NSLog(errorString);
+        
         return;
       }
       
