@@ -195,7 +195,11 @@
 		if ([result success])
 			[currentItem setStatus:ITEM_STATUS_FINISHED_WITH_SUCCESS];
 		else
-			[[queueItems objectAtIndex:currentTaskIndex] setStatus:ITEM_STATUS_FINISHED_WITH_FAILURE];
+    {
+			[currentItem setStatus:ITEM_STATUS_FINISHED_WITH_FAILURE];
+      if ([[result extendedErrorString] length] > 0)
+        [currentItem setResultString:[NSString stringWithFormat:@"%@ (%@)", [currentItem resultString], [result extendedErrorString]]];
+    }
 		[queueTable reloadData];
 	}
 }
