@@ -8,9 +8,6 @@
 #import <Foundation/Foundation.h>
 #import "MyItem.h"
 
-// these should be in numerical order of sorting that we'd like compareByCodec to use
-typedef enum _codecTypes {CODEC_UNDEFINED = -1, CODEC_MP3 = 0, CODEC_WMA = 1, CODEC_WAV = 2, CODEC_AA = 3} codecTypes;
-
 @interface Track : MyItem {
 @private
   NSString *title;
@@ -22,7 +19,6 @@ typedef enum _codecTypes {CODEC_UNDEFINED = -1, CODEC_MP3 = 0, CODEC_WMA = 1, CO
 	unsigned length;
 	unsigned trackNumber;
 	unsigned year;
-	codecTypes codec;
 	unsigned long long filesize;
 }
 - (id)initWithTrack:(Track *)track;
@@ -45,14 +41,12 @@ typedef enum _codecTypes {CODEC_UNDEFINED = -1, CODEC_MP3 = 0, CODEC_WMA = 1, CO
 - (void)setYear:(unsigned)newYear;
 - (unsigned)year;
 - (void)setTrackNumber:(unsigned)newTrackNumber;
-- (codecTypes)codec;
-- (NSString *)codecString;
 - (NSString *)njbCodec;
-- (void)setCodec:(codecTypes)newCodec;
 - (unsigned long long)filesize;
 - (NSString *)filesizeString;
 - (void)setFilesize:(unsigned long long)newFilesize;
 - (void)setValuesToTrack:(Track *)track;
+- (void)fileTypeFromExtension;
 
 - (NSComparisonResult)compareByLength:(Track *)other;
 - (NSComparisonResult)compareUnsignedInts:(unsigned)mine withOther:(unsigned)theirs;
