@@ -276,8 +276,10 @@ struct LIBMTP_playlist_struct {
  * MTP Album structure
  */
 struct LIBMTP_album_struct {
-  uint32_t album_id; /**< Unique album ID */
+  uint32_t album_id; /**< Unique playlist ID */
   char *name; /**< Name of album */
+  char *artist; /**< Name of album artist */
+  char *genre; /**< Genre of album */
   uint32_t *tracks; /**< The tracks in this album */
   uint32_t no_tracks; /**< The number of tracks in this album */
   LIBMTP_album_t *next; /**< Next album or NULL if last album */
@@ -345,6 +347,7 @@ int LIBMTP_Get_Supported_Devices_List(LIBMTP_device_entry_t ** const, int * cons
 int LIBMTP_Detect_Descriptor(uint16_t*,uint16_t*);
 LIBMTP_mtpdevice_t *LIBMTP_Get_First_Device(void);
 LIBMTP_error_number_t LIBMTP_Get_Connected_Devices(LIBMTP_mtpdevice_t **);
+uint32_t LIBMTP_Number_Devices_In_List(LIBMTP_mtpdevice_t *);
 void LIBMTP_Release_Device_List(LIBMTP_mtpdevice_t*);
 void LIBMTP_Release_Device(LIBMTP_mtpdevice_t*);
 void LIBMTP_Dump_Device_Info(LIBMTP_mtpdevice_t*);
