@@ -42,7 +42,7 @@
 #include "ptp-pack.c"
 
 /* To enable debug prints, switch on this */
-#define ENABLE_USB_BULK_DEBUG
+//#define ENABLE_USB_BULK_DEBUG
 
 /* OUR APPLICATION USB URB (2MB) ;) */
 #define PTPCAM_USB_URB		2097152
@@ -187,6 +187,9 @@ static const LIBMTP_device_entry_t mtp_device_table[] = {
   // This has no dual-mode so no need to unload any driver.
   // This is a Linux based device!
   { "SanDisk Sansa Connect", 0x0781, 0x7480, DEVICE_FLAG_NONE },
+  // Reported by Troy Curtis Jr.
+  { "SanDisk Sansa Express", 0x0781, 0x7460, DEVICE_FLAG_UNLOAD_DRIVER |
+                                             DEVICE_FLAG_BROKEN_MTPGETOBJPROPLIST },
   
 
   /*
@@ -354,6 +357,12 @@ static const LIBMTP_device_entry_t mtp_device_table[] = {
    */
   // Reported by Stefan Voss <svoss@web.de>
   {"TrekStor Vibez 8/12GB", 0x066f, 0x842a, DEVICE_FLAG_UNLOAD_DRIVER },
+  
+  /*
+   * Disney (have had no reports of this actually working.)
+   */
+  // Reported by XNJB user
+  {"Disney MixMax", 0x0aa6, 0x6021, DEVICE_FLAG_NONE },
 
   /*
    * Other strange stuff.
